﻿/*
Convert All Text to Outlines
Version 1.2
An InDesign CS2-CS4 JavaScript
OS: Mac OS X, Windows XP.
************************************************ English Description ************************************************
The Script is intended for Converts All Texts to Outlines.
Each line of text becomes a polygon object. 
When the converted text is a single letter that has no internal spaces or detached parts, 
the polygon contains only a single path. 

Script Options:	
1) "Move Created Objects to Layer" - if false, creates the outlines placed on top of the text on a layer of the facility, 
if true, drop-down list is chosen name of the new layer named "Converted Text" or the name of one of the existing layers for move created objects;
2) "Show Report" - display the report of converting text objects,
contains the number of objects "Story" with overflow.
Objects with overset text not converted,
Cells of tables with overflow of contents are ignored.

© 2009 Dmitriy Lapaev (d.lapaev@gmail.com)
FREEWARE. You use this script at your own fear and risk.
************************************************ Описание скрипта ************************************************
Скрипт предназначен для перевода в кривые всех текстов документа (Text Objects of Stories).

Настройки скрипта:
1) "Move Created Objects to Layer" - переместить созданные объекты на слой,
в выпадающем списке выбирается имя нового слоя с именем "Converted Text"
или имя одного из существующих слоев, при отключенной опции объекты помещаются поверх текста на слое объекта;
2) "Show Report" - отобразить отчет конвертирования текстовых объектов, 
содержит информацию о количестве объектов (Story) с переполнением текстов (Overset Text).
Объекты с переполнением текстов не конвертируются,
ячейки таблиц с переполнением содержания игнорируются.

Автор: Дмитрий Лапаев (d.lapaev@gmail.com)
Скрипт распространяется бесплатно, используйте на свое усмотрение.
*/

try {var myActDocument = app.activeDocument;} 
catch (e) {alert ("No Documents are Open! \nPlease Open a Document and try again."); exit();}
var mn = "\u00A9 \u0044\u006D\u0069\u0074\u0072\u0069\u0079 \u004C\u0061\u0070\u0061\u0079\u0065\u0076";
/* var delete_OriginalSt - if true, deletes the original text, if false, creates the outlines as separate object(s) on top of the text.
Удалять исходные текстовые объекты, при отключенной опции, созданные объекты помещаются поверх исходного текста.
Не рекомендуется включать данную опцию при наличии текстов на путях (Type on a Path), при заданном контуре текста (Stroke) и т.п.,
так как результат конвертирования не будет соответствовать исходному объекту. */
var delete_OriginalSt = false;
var newLayerName = "Converted Text";
var myScriptName = "Convert All Text to Outlines 1.2";
// версия InDesign
try {const InDver = app.version.substr(0, 1);}
catch (e) {alert (myScrName + "\nis not compatible with this version of InDesign!"); exit();}
// тип файловой системы (ОС)
var WonFS = File.fs;
if (WonFS == "Macintosh") {WonFS = "Mac OS X";}
// массив имен слоев документа
var myLayersNames = new Array ();
myLayersNames.push("New \"" + newLayerName + "\"");
for (var layersCnt = 0; layersCnt < myActDocument.layers.length; layersCnt++) {myLayersNames.push (myActDocument.layers[layersCnt].name);}

// диалог настроек скрипта
var CREATE_OUTLINES_Dialog = app.dialogs.add({name: myScriptName + " (" + "InDesign " + InDver + " on " + WonFS + ")"});	
with (CREATE_OUTLINES_Dialog.dialogColumns.add()) {
	with (borderPanels.add().dialogColumns.add()) {
		var moveCrPolygons = dialogRows.add().enablingGroups.add({staticLabel: "Move Created Objects to Layer: ", checkedState: !delete_OriginalSt});	
		var mySEL_Layer = moveCrPolygons.dropdowns.add({stringList: myLayersNames, selectedIndex: 0, minWidth: 260});
		var show_Report = checkboxControls.add({staticLabel: "Show Report", checkedState: true});
	}
	dialogRows.add().staticTexts.add({staticLabel: mn});
}

// отображаем диалог 
if (CREATE_OUTLINES_Dialog.show()) {	
	if (moveCrPolygons.checkedState) {
		var myPolygonsLayer;
		if (mySEL_Layer.selectedIndex != 0) {myPolygonsLayer = myActDocument.layers.item (myLayersNames[mySEL_Layer.selectedIndex]);}
		else {myPolygonsLayer = create_Layer (newLayerName);}
	}
	// counters (счетчики объектов)
	var convertedTextsCounter = 0;
	var createdObjectsCounter = 0;
	var oversetTextsCounter = 0;
	var movedObjectsCounter = 0;
	var CurrentText;
	var returnObjects = new Array();
	var myDocStoriesLength = myActDocument.stories.length;
	for (var StCnt = 0; StCnt < myDocStoriesLength; StCnt++) {	
		CurrentStory = myActDocument.stories[StCnt];
		for (var TextCnt = 0; TextCnt < CurrentStory.texts.length; TextCnt++) {
			CurrentText = CurrentStory.texts[TextCnt];
			if (CurrentText.contents != "") {
				try {
					returnObjects = CurrentText.createOutlines(delete_OriginalSt);
					convertedTextsCounter++;			
					createdObjectsCounter += returnObjects.length;
					if (moveCrPolygons.checkedState) {
						for (var mc = 0; mc  < returnObjects.length; mc ++) {
							try {
								returnObjects[mc].move(myPolygonsLayer);
								movedObjectsCounter++;
							}
							catch (e) {}
						}
					}			
				}
				catch (e) {
					if (CurrentStory.overflows) {oversetTextsCounter++;}
					// alert (e);
				}
			}
		}
	}
	// report
	if (show_Report.checkedState) {
		var reportTxt = "Create Outlines Report:\n\n● Stories: " + myDocStoriesLength + "\n● Converted Texts: " + convertedTextsCounter;
		if (createdObjectsCounter > 0) {reportTxt += "\n● Created Objects: " + createdObjectsCounter;}
		if (movedObjectsCounter > 0) {reportTxt += "\n● Moved to \"" + myPolygonsLayer.name + "\": " + movedObjectsCounter;}
		if (oversetTextsCounter > 0) {reportTxt += "\n● Found Stories with Overset text: " + oversetTextsCounter;}
		alert (reportTxt, myScriptName, false);
	}
}
CREATE_OUTLINES_Dialog.destroy();		
exit();

/* Функция создает слой документа с именем myDoc_LayerName. 
The function creates a layer with the name myDoc_LayerName.*/
function create_Layer (myDoc_LayerName) {
	var myNewLayer;
	// add new layer (создаем новый слой в документе)
	try {myNewLayer = app.activeDocument.layers.add ({name: myDoc_LayerName});}
	catch (e) {myNewLayer = app.activeDocument.layers.item (myDoc_LayerName);}
	with (myNewLayer) {	
		visible = true;
		locked = false;
		try {printable = true;} catch (e){}
		showGuides = true;
		ignoreWrap = false;
	}
	return myNewLayer;
}
// 16-17 июня 2008 года